<?php
/**
 * QuickLaunch Theme
 * Personalization Functions File
 *
 * @package QuickLaunch
 * @version 1.0
 * @since 1.0
 * @author brux <brux.romuar@gmail.com>
 */
 
/**
 * Applies the personalization options chosen by the user.
 *
 * @return void
 * @since 1.0
 */
function ql_apply_styles()
{
	$content_padding = get_option('ql-content-padding');
	$content_width = 500 - ($content_padding * 2);
?>

	<!-- Personalization options -->
	<style>
	body {
<?php if ( get_option('ql-bg-color') ): ?>background-color: <?php echo get_option('ql-bg-color') ?>; <?php endif; ?>
<?php if ( get_option('ql-bg-image') ): ?>background-image: url(<?php echo get_option('ql-bg-image') ?>);<?php endif; ?>

	}
	#wrap {
		padding: <?php echo $content_padding ?>px;
		width: <?php echo $content_width ?>px;
	}
	</style>
	<!-- End Personalization options -->

<?php
}

add_action('wp_head', 'ql_apply_styles');
 
/**
 * Receives and processes files uploaded through the personalization panel.
 *
 * @return void
 * @since 1.0
 */
function ql_upload()
{

	check_ajax_referer('quicklaunch-upload-file', '_wpnonce');

	// Grab file details and content
	$filename = $_FILES['file']['name'];
	$bits = file_get_contents($_FILES['file']['tmp_name']);
	
	// Make sure we have no errors
	if ( $_FILES['file']['error'] != 0 )
	{
		$data = array('msg' => 'Upload Error. Code '. $_FILES['file']['error']);
		$response = new QL_JSONResponse($data, false);
		$response->output();
	}
	
	// Do upload
	$upload = wp_upload_bits($filename, null, $bits);
	
	// Delete the temp file
	@unlink($_FILES['file']['tmp_name']);
	
	// If we have no errors, return the URL of the image as a response 
	if ( $upload['error'] === false )
	{
		$data = array(
			'url' => $upload['url']
		);
		$response = new QL_JSONResponse($data);
		$response->output();
	}
	else
	{
		$data = array('msg' => $upload['error']);
		$response = new QL_JSONResponse($data, false);
		$response->output();
	}

}
add_action('wp_ajax_ql_upload', 'ql_upload');
 
/**
 * Catches and handles the personalization info sent via AJAX.
 *
 * @return void
 * @since 1.0
 */
function ql_save_personalization()
{

	check_ajax_referer('quicklaunch-save-personalization', '_wpnonce');
	
	// Webiste Styles
	$bgcolor = $_POST['bgcolor'];
	$bgimage = $_POST['bgimage'];
	$centerimage = $_POST['centerimage'];
	
	$upload_dir = wp_upload_dir();
	
	// If we have a new background image, delete the old one
	$old_bgimage = get_option('ql-bg-image');
	if ( $old_bgimage != $bgimage )
	{
		$old_bgimage = str_replace($upload_dir['baseurl'], $upload_dir['basedir'], $old_bgimage);
		@unlink($old_bgimage);
	}
	
	// If we have a new center image, delete the old one
	$old_centerimage = get_option('ql-center-image');
	if ( $old_centerimage != $centerimage )
	{
		$old_centerimage = str_replace($upload_dir['baseurl'], $upload_dir['basedir'], $old_centerimage);
		@unlink($old_centerimage);
	}
	
	// Social Network URLs
	$twitter = trim($_POST['twitter']);
	$facebook = trim($_POST['facebook']);
	$linkedin = trim($_POST['linkedin']);
	$googleplus = trim($_POST['googleplus']);
	
	// Website content
	$title = trim($_POST['title']);
	$desc = trim($_POST['desc']);
	$content = trim($_POST['page-content']);
	
	// Stylings
	$btn_color = $_POST['btn_color'];
	$content_padding = intval($_POST['content_padding']);
	
	// Save the changes
	update_option('ql-bg-color', $bgcolor);
	update_option('ql-bg-image', $bgimage);
	update_option('ql-center-image', $centerimage);
	update_option('ql-twitter-url', $twitter);
	update_option('ql-facebook-url', $facebook);
	update_option('ql-linkedin-url', $linkedin);
	update_option('ql-googleplus-url', $googleplus);
	update_option('blogname', $title);
	update_option('blogdescription', $desc);
	update_option('ql-page-content', $content);
	update_option('ql-btn-color', $btn_color);
	update_option('ql-content-padding', $content_padding);
	
	$data = array('msg' => 'ok');
	$response = new QL_JSONResponse($data);
	$response->output();

}
add_action('wp_ajax_ql_save_personalization', 'ql_save_personalization');

/**
 * Returns TRUE if the user is currently personalizing the site/theme.
 *
 * @return boolean
 * @since 1.0
 */
function ql_is_personalizing()
{

	return defined('QL_PERSONALIZING');

}
 
?>