(function($) {
	
	function uploader_files_added(uploader, files) {
		var file = files[0];
		uploader.files = [file];
		notify('Uploading File...');
		setTimeout(function() {
			uploader.start();
		}, 5);
	}
	
	function uploader_error(uploader, error) {
		alert('Upload Error.\n'+ error);
	}

	function notify(msg) {
		$('#loading-indicator').html(msg)
							   .show();
		$('#admin-save-changes').hide()
								.blur();
	}
	
	function hide_notif() {
		$('#loading-indicator').hide();
		$('#admin-save-changes').show();
	}

	function save_changes() {
	
		var data = $('#personalization-form').serializeArray();
		
		data.push({ name: 'title', value: $('#site-title').text() });
		data.push({ name: 'desc', value: $('#site-desc').text() });
		data.push({ name: 'page-content', value: $('#page-content').html() });
		
		data.push({ name: 'action', value: 'ql_save_personalization' });
		data.push({ name: '_wpnonce', value: QLAdmin.save_nonce });
		
		$.post(QLAdmin.ajaxurl, data, function(r) {
			if (r.status == 'ok') {
				window.location = window.location.href.replace('?personalize', '');
			}
			else {
				alert(r.msg);
			}
		}, 'json');
		
	}

	$(document).ready(function() {
		
		// Move the admin palette next to the main content
		var palette = $('#admin');
		if (palette.length) {
		
			var palette_width = palette.width();
			var content_pos = $('#wrap').offset();
			var palette_x = content_pos.left - palette_width - 40;
			
			palette.css('left', palette_x);
			
		}
		
		// Init the colorpicker
		var bgcolor = $('#bgcolor');
		bgcolor.ColorPicker({
			color: bgcolor.val(),
			onShow: function(picker) {
				var offset = $('#change-bg-color > a').offset();
				$(picker).css({
					top: offset.top + bgcolor.height() + 5,
					left: offset.left
				}).show();
				return false;
			},
			onChange: function(hsb, hex, rgb) {
				hex = '#'+ hex;
				bgcolor.val(hex);
				$('body').css('background-color', hex);
			}
		});
		$('#change-bg-color').click(function(evt) {
			evt.preventDefault();
			bgcolor.click();
		});
		
		// Generate our upload url
		var upload_url = QLAdmin.ajaxurl + '?action=ql_upload&_wpnonce=' + QLAdmin.upload_nonce;
		
		// Create our default uploader params
		var upload_params = {
			runtimes: 'html5,flash',
			max_file_size: '10mb',
			url: upload_url,
			flash_swf_url: QLAdmin.siteurl + '/wp-includes/js/plupload/plupload.flash.swf',
			filters: [
				{ title: 'Image Files', extensions: 'jpg,gif,png' }
			]
		};
		
		// Upload background image
		upload_params.browse_button = 'upload-bg-link';
		var bg_uploader = new plupload.Uploader(upload_params);
		bg_uploader.bind('FilesAdded', uploader_files_added);
		bg_uploader.bind('Error', uploader_error);
		bg_uploader.bind('FileUploaded', function(up, file, response) {
			var r = $.parseJSON(response.response);
			if (r.status == 'ok') {
				$('body').css('background-image', 'url('+ r.url +')');
				$('#bgimage').val(r.url);
			}
			else {
				alert('Upload Error.\n'+ r.msg);
			}
			hide_notif();
		});
		bg_uploader.init();
		
		// Upload center image
		upload_params.browse_button = 'upload-centerimg-link';
		var bg_uploader = new plupload.Uploader(upload_params);
		bg_uploader.bind('FilesAdded', uploader_files_added);
		bg_uploader.bind('Error', uploader_error);
		bg_uploader.bind('FileUploaded', function(up, file, response) {
			var r = $.parseJSON(response.response);
			if (r.status == 'ok') {
				var html = '<img src="'+ r.url +'" alt="'+ file.name +'" width="460" height="300">';
				$('#center-image').html(html);
				$('#centerimage').val(r.url);
			}
			else {
				alert('Upload Error.\n'+ r.msg);
			}
			hide_notif();
		});
		bg_uploader.init();
		
		// Add editable classes to the site title, tagline and main page content
		$('#site-title,#site-desc,#page-content').prop('contenteditable', true)
												 .addClass('editable');
		
		// Button Colors
		$('#btn-color').change(function(evt) {
			console.log(this.value);
			$('#newsletter-submit').attr('class', 'btn '+ this.value);
		});
						 
		// Initialize content padding slider
		$('#content-padding-slider').noUiSlider('init', {
			dontActivate: 'lower',
			startMax: parseInt($('#content-padding').val()),
			Maxvalue: 100,
			tracker: function() {
				var val = Math.round($('#content-padding-slider').noUiSlider('getValue', {point: 'upper'}));
				var content_width = 500 - (val * 2);
				$('#wrap').css({
					padding: val,
					width: content_width
				});
				$('#center-image > img').width(content_width);
				$('#content-padding').val(val);
			}
		});
		
		// Handle save changes
		$('#admin-save-changes').click(function(evt) {
			evt.preventDefault();
			notify('Saving Changes...');
			save_changes();
		});
		
	});

})(jQuery);